import { create } from 'zustand';

// src/use-modal.ts
var stores = /* @__PURE__ */ new Map();
function getModalStore(type) {
  return stores.get(type);
}
function setModalStore(type, store) {
  stores.set(type, store);
  return store;
}
function createModalStore(initialData) {
  return create((set) => ({
    actions: {
      onClose: () => {
        set({ isOpen: false });
      },
      onOpen: (data) => {
        set({ data, isOpen: true });
      }
    },
    data: initialData,
    isOpen: false
  }));
}
function useModalActions(type) {
  let store = getModalStore(type);
  if (!store) {
    store = setModalStore(type, createModalStore());
  }
  return store((state) => state.actions);
}
function useModalOpen(type) {
  let store = getModalStore(type);
  if (!store) {
    store = setModalStore(type, createModalStore());
  }
  return store((state) => state.isOpen);
}
function useModalData(type, initialData) {
  let store = getModalStore(type);
  if (!store) {
    store = setModalStore(type, createModalStore(initialData));
  }
  return store((state) => state.data ?? initialData);
}
function switchModal(currentType, targetType) {
  const currentStore = getModalStore(currentType);
  const targetStore = getModalStore(targetType);
  if (currentStore && targetStore) {
    currentStore.setState({ isOpen: false });
    targetStore.setState({ isOpen: true });
  } else if (!targetStore) {
    const newStore = createModalStore();
    setModalStore(targetType, newStore);
    newStore.setState({ isOpen: true });
  }
}

export { switchModal, useModalActions, useModalData, useModalOpen };
//# sourceMappingURL=out.js.map
//# sourceMappingURL=chunk-BVDI3RWB.mjs.map